@@ -564,8 +564,7 @@ class Builder(Update):
         logfile = self._get_log_file()
         deo = self.get_default_emerge_opts()
 
-        driver_list = list(chain(self.NvidiaDriver(builder_path),
-                                 self.AtiDriver(builder_path)))
+        driver_list = list(self.NvidiaDriver(builder_path))
         distrdir = path.join(builder_path, 'usr/portage/distfiles')
         pkgdir = path.join(builder_path, 'usr/portage/packages')
         for target_dn in (distrdir, pkgdir):
